@@ -356,7 +356,7 @@ create_advanced_settings_page (RtcomDialogContext *context)
       Longcat *plugin;
       LongcatPrivate *priv;
 
-      xml = glade_xml_new (PLUGIN_XML_DIR "/longcat-advanced.glade", NULL,
+      xml = glade_xml_new (PLUGIN_XML_DIR "/longcat-advanced-1.glade", NULL,
           GETTEXT_PACKAGE);
       rtcom_dialog_context_take_obj (context, G_OBJECT (xml));
       dialog = glade_xml_get_widget (xml, "advanced");
